@@ -34,6 +34,7 @@
 #include "Rgeometry.h"
 #define qh_QHimport
 #include "qhull_a.h"
+#include <unistd.h>              /* For unlink() */
 
 SEXP delaunayn(const SEXP p, const SEXP options)
 {
@@ -49,11 +50,13 @@ SEXP delaunayn(const SEXP p, const SEXP options)
 
   /* We cannot print directly to stdout in R, and the alternative of
      using R_Outputfile does not seem to work for all
-     architectures. Therefore set outfile to NULL, which supresses any
-     output when qh_new_qhull() is called. */
-  FILE *outfile = NULL;
-   /* qh_fprintf() in userprint.c has been redefined so that a NULL
-      errfile results in printing via REprintf(). */
+     architectures. Setting outfile to NULL, is not an option, as an
+     open file handle is required for a call to freopen in the Qhull
+     code when qh_new_qhull() is called. Therefore use the ersatz
+     stdout, tmpstdout (see below). */
+  /* FILE *outfile = NULL; */
+  /* qh_fprintf() in userprint.c has been redefined so that a NULL
+     errfile results in printing via REprintf(). */
   FILE *errfile = NULL;       
 
 	if(!isString(options) || length(options) != 1){
@@ -89,7 +92,16 @@ SEXP delaunayn(const SEXP p, const SEXP options)
 				pt_array[dim*i+j] = REAL(p)[i+n*j];
 		ismalloc = False;   /* True if qhull should free points in qh_freeqhull() or reallocation */
 
-		exitcode = qh_new_qhull(dim, n, pt_array, ismalloc, flags, outfile, errfile); 
+    /* Jiggery-pokery to create and destroy the ersatz stdout, and the
+       call to qhull itself. */    
+    const char *name;
+    name = R_tmpnam("Rf", R_TempDir);
+    tmpstdout = fopen(name, "w");
+		exitcode = qh_new_qhull(dim, n, pt_array, ismalloc, flags, tmpstdout, errfile); 
+    fclose(tmpstdout);
+    unlink(name);
+    free((char *) name); 
+    
 		if (!exitcode) {                    /* 0 if no error from qhull */
 
 			facetT *facet;                  /* set by FORALLfacets */
